@@ -35,6 +35,7 @@
 namespace QApt {
 
 class Backend;
+class MarkingErrorInfo;
 
 /**
  * PackagePrivate is a class containing all private members of the Package class
@@ -52,15 +53,6 @@ class Q_DECL_EXPORT Package
 {
 
 public:
-   /**
-    * Constructor. You will most likely never use this, and it will probably
-    * become private in QApt2.
-    *
-    * @param parent The backend that this package is being made a child of
-    * @param packageIter The underlying object representing the package in APT
-    */
-    Package(QApt::Backend* parent, pkgCache::PkgIterator &packageIter);
-
    /**
     * Destructor.
     */
@@ -253,7 +245,6 @@ public:
     */
     QUrl screenshotUrl(QApt::ScreenshotType type) const;
 
-    // TODO: QApt2: Return a QDateTime so that KDE apps can localize
    /**
     * Returns the date when Canonical's support of the package ends.
     *
@@ -261,7 +252,7 @@ public:
     *         supported now, then it will return an empty QString. The date
     *         will be localized in the "month year" format.
     */
-    QString supportedUntil() const;
+    QDateTime supportedUntil() const;
 
    /**
     * Returns the specified field of the package's debian/control file
@@ -407,22 +398,31 @@ public:
     */
     bool isForeignArch() const;
 
+    /// Returns a list of DependencyItems that this package depends on.
     QList<DependencyItem> depends() const;
 
+    /// Returns a list of DependencyItems that required to install this package.
     QList<DependencyItem> preDepends() const;
 
+    /// Returns a list of DependencyItems that this package suggests to be installed.
     QList<DependencyItem> suggests() const;
 
+    /// Returns a list of DependencyItems that this package recommends to be installed.
     QList<DependencyItem> recommends() const;
 
+    /// Returns a list of DependencyItems that conflict with this package
     QList<DependencyItem> conflicts() const;
 
+    /// Returns a list of DependencyItems that this package replaces.
     QList<DependencyItem> replaces() const;
 
+    /// Returns a list of DependencyItems that this package obsoletes.
     QList<DependencyItem> obsoletes() const;
 
+    /// Returns a list of DependencyItems that this package breaks.
     QList<DependencyItem> breaks() const;
 
+    /// Returns a list of DependencyItems that this package enhances.
     QList<DependencyItem> enhances() const;
 
    /**
@@ -477,23 +477,11 @@ public:
     QStringList enhancedByList() const;
 
    /**
-    * If a package is in a broke state, this function returns why the package
+    * If a package is in a broke state, this function returns a why the package
     * is broken by showing all errors in the dependency cache that marking the
     * package has caused.
-    *
-    * The format is a bit complex. The QHash contains a QHash corresponding to
-    * each QApt::BrokenReason. This internal QHash is a QString corresponding to
-    * a QVariantMap. The QString in this case is a package that is broken by this
-    * QApt::Package, and the QVariantMap contails details on why the corresponding
-    * package is broken. These details may vary based on what QApt::BrokenState
-    * the QHash corresponds to.
-    *
-    * \return A @c QHash of reasons why the package is broken, corresponding to a
-    * QApt::BrokenReason
     */
-    // TODO: QApt2: Get rid of this insane thing and use a proper OO scheme,
-    // perhaps something like DependencyInfo
-    QHash<int, QHash<QString, QVariantMap> > brokenReason() const;
+    QList<QApt::MarkingErrorInfo> brokenReason() const;
 
    /**
     * Returns whether the package is signed with a trusted GPG signature.
@@ -617,6 +605,14 @@ public:
 private:
     PackagePrivate *const d;
 
+    /**
+     * Internal constructor.
+     *
+     * @param parent The backend that this package is being made a child of
+     * @param packageIter The underlying object representing the package in APT
+     */
+     Package(QApt::Backend* parent, pkgCache::PkgIterator &packageIter);
+
     /**
      * Returns the internal APT representation of the package
      *
@@ -624,6 +620,14 @@ private:
      */
      const pkgCache::PkgIterator &packageIterator() const;
 
+     /**
+      * Returns a set of state flags that won't change until the next
+      * cache reload, and excluding any flags that are able to change.
+      * Used internally to avoid having to calculate mutable flags when we know
+      * the flag we want to check is immutable.
+      */
+     int staticState() const;
+
      friend class Backend;
 };
 
